@@ -1,7 +1,7 @@
 /*
  * hist - definitions for command history module
  *
- * Copyright (C) 1999-2007,2014  David I. Bell
+ * Copyright (C) 1999-2007,2014,2021  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -17,10 +17,6 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.3 $
- * @(#) $Id: hist.h,v 30.3 2014/08/24 21:56:51 chongo Exp $
- * @(#) $Source: /usr/local/src/bin/calc/RCS/hist.h,v $
- *
  * Under source code control:	1993/05/02 20:09:20
  * File existed as early as:	1993
  *
@@ -40,7 +36,7 @@
 #endif
 
 #ifndef HIST_SIZE
-#define HIST_SIZE		(1024*10)
+#define HIST_SIZE		(1024*32)
 #endif
 
 
@@ -50,7 +46,7 @@
 #define HOMECHAR	'~'	/* char which indicates home directory */
 #define DOTCHAR		'.'	/* char which indicates current directory */
 #define PATHCHAR	'/'	/* char which separates path components */
-#if defined(__MSDOS__) || defined(__WIN32)
+#if defined(_WIN32) || defined(_WIN64)
 #define LISTCHAR	';'	/* char which separates paths in a list */
 #else
 #define LISTCHAR	':'	/* char which separates paths in a list */
@@ -62,7 +58,7 @@
  * not prevent calling the other routines, but fancy command line editing
  * is then disabled.
  */
-#define HIST_SUCCESS	0	/* successfully inited */
+#define HIST_SUCCESS	0	/* successfully initialized */
 #define HIST_INITED	1	/* initialization is already done */
 #define HIST_NOFILE	2	/* bindings file could not be read */
 #define HIST_NOTTY	3	/* terminal modes could not be set */
